@@ -1,5 +1,23 @@
-#ifndef _SIGC_LIMIT_REFERENCE_H_
-#define _SIGC_LIMIT_REFERENCE_H_
+/*
+ * Copyright 2005 - 2016, The libsigc++ Development Team
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ */
+
+#ifndef SIGC_LIMIT_REFERENCE_H
+#define SIGC_LIMIT_REFERENCE_H
 
 #include <sigc++/visit_each.h>
 #include <sigc++/type_traits.h>
@@ -28,17 +46,25 @@ namespace sigc
  *
  * - @e T_type The type of the reference.
  */
-template <class T_type,
+template <typename T_type,
   bool I_derives_trackable = std::is_base_of<trackable, std::decay_t<T_type>>::value>
 class limit_reference
 {
 public:
   using reference_type = typename std::remove_volatile_t<T_type>;
 
+  limit_reference() = delete;
+
   /** Constructor.
-   * @param _A_target The reference to limit.
+   * @param target The reference to limit.
    */
-  limit_reference(reference_type& _A_target) : visited(_A_target) {}
+  explicit limit_reference(reference_type& target) : visited(target) {}
+
+  limit_reference(const limit_reference& src) = default;
+  limit_reference& operator=(const limit_reference& src) = default;
+
+  limit_reference(limit_reference&& src) = default;
+  limit_reference& operator=(limit_reference&& src) = default;
 
   /** Retrieve the entity to visit for visit_each().
    * Depending on the template specialization, this is either a derived reference, or
@@ -62,16 +88,16 @@ private:
 /** limit_reference object for a class that derives from trackable.
  * - @e T_type The type of the reference.
  */
-template <class T_type>
+template <typename T_type>
 class limit_reference<T_type, true>
 {
 public:
   using reference_type = typename std::remove_volatile_t<T_type>;
 
   /** Constructor.
-   * @param _A_target The reference to limit.
+   * @param target The reference to limit.
    */
-  limit_reference(reference_type& _A_target) : visited(_A_target), invoked(_A_target) {}
+  limit_reference(reference_type& target) : visited(target), invoked(target) {}
 
   /** Retrieve the entity to visit for visit_each().
    * Depending on the template specialization, this is either a derived reference, or
@@ -105,20 +131,20 @@ private:
  * visit() method.
  * @tparam T_type The type of the reference
  * @tparam T_action The type of functor to invoke.
- * @param _A_action The functor to invoke.
- * @param _A_target The visited instance.
+ * @param action The functor to invoke.
+ * @param target The visited instance.
  */
-template <class T_type>
+template <typename T_type>
 struct visitor<limit_reference<T_type>>
 {
-  template <class T_action>
-  static void do_visit_each(const T_action& _A_action, const limit_reference<T_type>& _A_target)
+  template <typename T_action>
+  static void do_visit_each(const T_action& action, const limit_reference<T_type>& target)
   {
-    sigc::visit_each(_A_action, _A_target.visit());
+    sigc::visit_each(action, target.visit());
   }
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 } /* namespace sigc */
 
-#endif /* _SIGC_LIMIT_REFERENCE_H_ */
+#endif /* SIGC_LIMIT_REFERENCE_H */
