@@ -21,21 +21,15 @@
 #include <tuple>
 #include <utility>
 
-namespace sigc
-{
+namespace sigc::internal {
 
-namespace internal
-{
-
-namespace detail
-{
+namespace detail {
 
 template <typename T, typename Seq>
 struct tuple_type_start_impl;
 
 template <typename T, std::size_t... I>
-struct tuple_type_start_impl<T, std::index_sequence<I...>>
-{
+struct tuple_type_start_impl<T, std::index_sequence<I...>> {
   using type = std::tuple<typename std::tuple_element<I, T>::type...>;
 };
 
@@ -45,21 +39,20 @@ struct tuple_type_start_impl<T, std::index_sequence<I...>>
  * Get the type of a tuple with just the first @len items.
  */
 template <typename T, std::size_t len>
-struct tuple_type_start : detail::tuple_type_start_impl<T, std::make_index_sequence<len>>
-{
-};
+struct tuple_type_start
+  : detail::tuple_type_start_impl<T, std::make_index_sequence<len>> {};
 
-namespace detail
-{
+namespace detail {
 
 template <typename T, typename Seq>
 struct tuple_start_impl;
 
 template <typename T, std::size_t... I>
-struct tuple_start_impl<T, std::index_sequence<I...>>
-{
-  static constexpr decltype(auto) tuple_start(T&& t)
-  {
+struct tuple_start_impl<T, std::index_sequence<I...>> {
+  static
+  constexpr
+  decltype(auto)
+  tuple_start(T&& t) {
     constexpr auto size = std::tuple_size<std::decay_t<T>>::value;
     constexpr auto len = sizeof...(I);
     static_assert(len <= size, "The tuple size must be less than or equal to the length.");
@@ -75,10 +68,10 @@ struct tuple_start_impl<T, std::index_sequence<I...>>
  * Get the tuple with the last @a len items of the original.
  */
 template <std::size_t len, typename T>
-constexpr decltype(auto) // typename tuple_type_end<T, len>::type
-  tuple_start(T&& t)
-{
-  // We use std::decay_t<> because tuple_size is not defined for references.
+constexpr
+decltype(auto) // typename tuple_type_end<T, len>::type
+tuple_start(T&& t) {
+  //We use std::decay_t<> because tuple_size is not defined for references.
   constexpr auto size = std::tuple_size<std::decay_t<T>>::value;
   static_assert(len <= size, "The tuple size must be less than or equal to the length.");
 
@@ -86,8 +79,6 @@ constexpr decltype(auto) // typename tuple_type_end<T, len>::type
     std::forward<T>(t));
 }
 
-} // namespace internal
+} // namespace sigc::internal;
 
-} // namespace sigc
-
-#endif // SIGC_TUPLE_UTILS_TUPLE_START_H
+#endif //SIGC_TUPLE_UTILS_TUPLE_START_H
